#!/bin/bash -p
# Copyright 2015,2019-2020 VMware, Inc.  All rights reserved.
#
# This executable starts and stops the VMware Remote Console services.
#

# Print a variable, even if its value is -n (unlike echo).
print_var() {
   printf -- %s "$1"
}

# Canonicalize the path of an existing directory.
canonicalize_dir() {
   # Bash's cd builtin can write to stdout.
   (cd -- "$1" >/dev/null && pwd -P)
}

# Canonicalize the path of an existing file.
canonicalize_file() {
   local file="$1"

   while [ -h "$file" ]; do
      file="`readlink -- "$file"`"
   done

   local dir="`dirname -- "$file"`"
   # 'dir' is a directory, or a symlink to a directory. Canonicalize it.
   print_var "`canonicalize_dir "$dir"`"/"`basename -- "$file"`"
}

# Stop and remove a privileged helper.
stopPrivilegedHelper() {
   local helper="$1"
   set +e
   launchctl list "${helper}" >/dev/null 2>&1
   if [[ "$?" == "0" ]]; then
      launchctl stop "${helper}" || true
      launchctl unload "${HELPERPLIST_DIR}/${helper}.plist" || true
   fi
   set -e
   rm -f "${HELPER_DIR}/${helper}" || true
   rm -f "${HELPERPLIST_DIR}/${helper}.plist" || true
}


# To debug, uncomment the next 2 lines.
#set -x
#exec >>/tmp/debug 2>&1

set -e
# This executable runs with root privileges, so hardcode a PATH where
# unprivileged users cannot write.
export PATH=/bin:/sbin:/usr/bin:/usr/sbin

# We might have inherited the umask of the calling user. This executable runs
# with root privileges, so hardcode a reasonable and deterministic umask.
# Was bug 923795.
umask 022

THIS="`canonicalize_file "$0"`"
SERVICE_DIR="`dirname -- "$THIS"`"
LIBDIR="`dirname -- "$SERVICE_DIR"`"
HELPER_DIR='/Library/PrivilegedHelperTools'
HELPERPLIST_DIR='/Library/LaunchDaemons'

# Main code

case "$1" in
--start)
   stopPrivilegedHelper com.vmware.vmrc.CDSHelper
   if retString=`"$LIBDIR/vmware-usbarbitrator"`; then
      echo "Started USB arbitration service"
   else
      logger -s -t "VMware Remote Console 00000" \
         "Error: Unable to start the USB arbitration service. Error: $retString [$?]"
      exit 1
   fi
   ;;

--stop)
   "$LIBDIR/vmware-usbarbitrator" --kill || true
   stopPrivilegedHelper com.vmware.vmrc.InstallHelper
   stopPrivilegedHelper com.vmware.vmrc.CDSHelper
   ;;

*)
   exit 1
esac
